caellion-python-commons: caellion.pycommons.stringutil.unixpassword.NewlineEmptyException Class Reference

caellion-python-commons

caellion.pycommons.stringutil.unixpassword.NewlineEmptyException Class Reference

This exception is raised when an empty line separator string is encountered. More...

Inheritance diagram for caellion.pycommons.stringutil.unixpassword.NewlineEmptyException:

## Detailed Description

This exception is raised when an empty line separator string is encountered.

Definition at line 30 of file unixpassword.py.

The documentation for this class was generated from the following file:

- caellion/pycommons/stringutil/unixpassword.py